#!/bin/gawk -f 
#
# Collect acquired studies for the billing page by processing the output of viewlog.sh
#
# Parameters:
#
# Out: output file for the list of acquired studies
# Sum: output file for summary information
# Ign: file with list of studies to be ignored in the list
# 
# Last Updated     : $Author: tnemeth $
# Update Date Time : $Date: 2014/04/29 14:40:51 $
# RCS File Name    : $RCSfile: collectstudies.awk,v $
# RCS Revision     : $Revision: 1.6 $
# Locked by        : $Locker:  $
# Symbolic name    : $Name:  $
# State            : $State: Exp $
#



function createLogDate(year, month, day, time) {
	d = length(day) == 1 ? "0" day : day;
#	print "DEBUG: " year " " m[month] " " day " (" d ")";
	return year m[month] d "_" time;
}


BEGIN {
	# Fill ignore arreay from ignore file
	while (0 < (getline < Ign)) {
		if ( substr($1,1,1) != "#" )
			ignore[$1] = 1;
	}

	# create month array to convert 
	m["Jan"] = "01";
	m["Feb"] = "02";
	m["Mar"] = "03";
	m["Apr"] = "04";
	m["May"] = "05";
	m["Jun"] = "06";
	m["Jul"] = "07";
	m["Aug"] = "08";
	m["Sep"] = "09";
	m["Oct"] = "10";
	m["Nov"] = "11";
	m["Dec"] = "12";
}

( $8 == "STUDY" && $9 == "acquire" ) {
	# STUDY acquire entry
	if (ignore[$12] == 1) {
		# study is in the ignore list
		next;
	}

	if (styiuid[$12] == 1) {
		# Re-sent study, the study is alread on the acquired list
		next;
	}
	
	logd[$12] = createLogDate($1, $2, $3, $4);
	styiuid[$12] = 1;
	pname[$12] = $13;
	mod[$12] = $14;
	pid[$12] = $23;
	accno[$12] = $24;
	stydate[$12] = $25;
	instname[$12] = $26;
	stydescr[$12] = $27;
	if( $18 == "split" ) {
		derived[$12] = "SPLIT";	
	}
	else if( $18 == "merge" ) {
		derived[$12] = "MERGED";
	}
	next;
}
		
( $8 == "OBJECT" && $9 == "acquire" ) {
	# Object acquire entry
	if (obj[$11] == 1) {
		# re-sent object, has already been acquired 
		next;
	}

	obj[$11] = 1;
	if ($16 != "-")
		size[$12] += $16;
	if ($22 == "report")
		author[$12] = $23;

	# Fill study information missing from the STUDY acquire entry
	if (pname[$12] == "-" || pname[$12] == "")
		pname[$12] = $13;
	if (mod[$12] == "-" || mod[$12] == "")
		mod[$12] = $14;
	if (pid[$12] == "-" || pid[$12] == "")
		pid[$12] = $23;
	if (stydate[$12] == "-" || stydate[$12] == "")
		stydate[$12] = $25;
	if (instname[$12] == "-" || instname[$12] == "")
		instname[$12] = $26;
	if (stydescr[$12] == "-" || stydescr[$12] == "")
		stydescr[$12] = $27;
	next;
}

( $8 == "OTHER" && $9 == "acquire" ) {
	# OTHER acquire - can it be happen ??
	if (pname[$12] == "-" || pname[$12] == "")
		pname[$12] = $13;
	if (mod[$12] == "-" || mod[$12] == "")
		mod[$12] = $14;
	if ($16 != "-")
		size[$12] += $16;
	next;
}

( $8 == "STUDY" && $9 == "mergestudy" && $22 == "study_created" ) {
   derived[$12] = "MERGED";
}

( $8 == "STUDY" && $9 == "split" && $22 == "study_created" ) {
   derived[$12] = "SPLIT";
}
	

END {
	num = 0;
	total = 0;
	for (i in styiuid) {
		if ( HideDerived == "true" && derived[i] != "" ) {
			continue;
		}
		num++;
		if (size[i] != "" && size[i] != "-")
			total += size[i];
	}
	
	print "TOTAL " num " " total > Sum;
	printf("") > Out;

	if ( TotalOnly == "true" ) {
		exit 0;
	}

	for (study in styiuid) { \
		if ( HideDerived == "true" && derived[study] != "" ) {
			continue;
		}

		if ( pname[study] == "" )
			pname[study] = "-";
		if ( mod[study] == "" )
			mod[study] = "-";
		if ( size[study] == "" )
			size[study] = "-";
		if ( pid[study] == "" )
			pid[study] = "-";
		if ( accno[study] == "" )
			accno[study] = "-";
		if ( stydate[study] == "" )
			stydate[study] = "-";
		if ( instname[study] == "" )
			instname[study] = "-";
		if ( stydescr[study] == "" )
			stydescr[study] = "-";
		if ( derived[study] == "" )
			derived[study] = "-";
		if ( logd[study] == "" )
			logd[study] = "-";
		if ( author[study] == "" )
			author[study] = "-";

		print study " " pname[study] " " mod[study] " " size[study] " " pid[study] " " accno[study] \
						" " stydate[study] " " instname[study] " " stydescr[study] " " derived[study] " " logd[study] " " author[study] >> Out;
	}
}
