#!/bin/bash
#
# Component: log
#
# Description:
#  Sends compressed log files in email to address(es) configured in $CONF/log.cnf
#
# Usage:
#   logsend.sh <logfile1.tar.gz> <logfile2.tar.gz> ...
#
# Last Updated     : $Author$
# Update Date Time : $Date$
# RCS File Name    : $RCSfile$
# RCS Revision     : $Revision$
# Locked by        : $Locker$
# Symbolic name    : $Name$
# State            : $State$
#


. $HOME/etc/setenv.sh

LOGGER="/usr/bin/logger"
TAG="logsend[$$]"


addfile_()
{
  cat << ENDOFADDFILE >> $MFILE
--$BOUNDARY
Content-Type: application/x-tgz;  name="$1"
Content-Transfer-Encoding: base64
Content-Disposition: attachment; filename="$1"

ENDOFADDFILE

  cat $LOGMAILTMP/$1 >> $MFILE
  echo >> $MFILE
}


if [ -z "$1" ] ; then
  $LOGGER -p $LOG_FACILITY.err -t "$TAG" "Missing parameter"
  exit 1
fi


if [ ! -f "$CONF/log.cnf" ] ; then
  $LOGGER -p $LOG_FACILITY.err -t "$TAG" "Missing config file"
  exit 1
fi

. $CONF/log.cnf


if [ -z "${MAIL_TO}${MAIL_CC}${MAIL_BCC}" ] ; then
  $LOGGER -p $LOG_FACILITY.err -t "$TAG" "No recipients configured"
  exit 1
fi

# [ -z "$SENDER" ] && SENDER="From: Log Sender <logsender@imagemedical.com>"


LOGMAILTMP=$TMP/logmail.$$

[ ! -d "$LOGMAILTMP" ] && mkdir $LOGMAILTMP

FILES=""

HNAME=`hostname`
SHORTHNAME=`hostname -s`
DATE=`date +"%Y=%m%d%H%M=%S"`
MDATE=`date +"%A %B %d %r %Z %Y"`
SDATE=`date +"%Y/%m/%d %H:%M %Z"`

BOUNDARY="$HNAME($$)$DATE.bergenyestzerge"


while [ -n "$1" ] ; do
  FNAME=`basename $1`

  $LOGGER -p $LOG_FACILITY.info -t "$TAG" "Base64 encode $FNAME"
  uuencode --base64 $1 /dev/stdout | tail -n +2 | grep -v ^====$ > $LOGMAILTMP/$FNAME

  if [ $? -ne 0 ] ; then
    $LOGGER -p $LOG_FACILITY.error -t "$TAG" "Error encoding $FNAME"
  else
    FILES="$FILES $FNAME"
  fi
  shift
done


MFILE="$LOGMAILTMP/mail.file"

[ -z "$MAIL_FROM" ] && MAIL_FROM="Support <support@erad.com>"

> $MFILE

LOGTO=""
echo "From: $MAIL_FROM" >> $MFILE
if [ -n "$MAIL_TO" ] ; then
  echo "To: $MAIL_TO" >> $MFILE
  LOGTO="$MAIL_TO"
fi
if [ -n "$MAIL_CC" ] ; then
  echo "Cc: $MAIL_CC" >> $MFILE
  LOGTO="$LOGTO, $MAIL_CC"
fi
if [ -n "$MAIL_BCC" ] ; then
  echo "Bcc: $MAIL_BCC" >> $MFILE
  LOGTO="$LOGTO, $MAIL_BCC"
fi



cat << ENDOFMAILFILE >> $MFILE
Subject: EIM Log Files of $SHORTHNAME at $SDATE
Content-Type: Multipart/Mixed; boundary="$BOUNDARY"


--$BOUNDARY
Content-Type: text/plain; charset="us-ascii"
Conent-Transfer-Encoding: 7bit

eRAD Inc. log files
$MDATE



ENDOFMAILFILE

for file in $FILES ; do
  addfile_ $file
  rm $LOGMAILTMP/$file
done

echo "--$BOUNDARY--" >> $MFILE


cat $MFILE | /usr/sbin/sendmail -t

if [ $? -ne 0 ] ; then
  $LOGGER -p $LOG_FACILITY.err -t "$TAG" "Error sending $FILES to $LOGTO [mail saved as $MFILE]"
  exit 1
fi

$LOGGER -p $LOG_FACILITY.info -t "$TAG" "$FILES are sent to $LOGTO"

rm $MFILE
rmdir $LOGMAILTMP

